/**
 * Copyright (C) 2009-2016 Tatjana (Tanja) Kostic
 * <p>
 * This file belongs to jCleanCim, a tool supporting tasks of UML model managers for IEC TC57 CIM
 * and 61850 models.
 * <p>
 * This program is free software: you can redistribute it and/or modify it under the terms of the
 * GNU Lesser General Public License version 3.
 * <p>
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details. You should have received a copy of the GNU Lesser
 * General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package org.tanjakostic.jcleancim.docgen.collector;

import org.tanjakostic.jcleancim.model.TextDescription.TextKind;
import org.tanjakostic.jcleancim.util.Util;

/**
 * @author tatjana.kostic@ieee.org
 * @version $Id: FormatInfo.java 15 2016-07-12 15:11:42Z dev978 $
 */
public class FormatInfo {

	private final TextKind _kind;
	private final Integer _fmtIdx;

	/**
	 * Constructor; if you don't need formatting, just use null.
	 *
	 * @param kind
	 *            kind of formatting
	 * @param fmtIdx
	 *            index of the formattable column
	 */
	public FormatInfo(TextKind kind, Integer fmtIdx) throws IllegalArgumentException {
		Util.ensureNotNull(kind, "kind");
		Util.ensureNotNull(fmtIdx, "fmtIdx");

		_kind = kind;
		_fmtIdx = fmtIdx;
	}

	/** Returns kind of this format. */
	public TextKind getKind() {
		return _kind;
	}

	/** Returns the index of the column that may contain formatting. */
	public Integer getFormattedColumnIdx() {
		return _fmtIdx;
	}

	@Override
	public String toString() {
		return String.format("format: %s in column %s", getKind(), getFormattedColumnIdx());
	}
}
