/**
 * Copyright (C) 2009-2016 Tatjana (Tanja) Kostic
 * <p>
 * This file belongs to jCleanCim, a tool supporting tasks of UML model managers for IEC TC57 CIM
 * and 61850 models.
 * <p>
 * This program is free software: you can redistribute it and/or modify it under the terms of the
 * GNU Lesser General Public License version 3.
 * <p>
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details. You should have received a copy of the GNU Lesser
 * General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package org.tanjakostic.jcleancim.docgen.writer;

import org.tanjakostic.jcleancim.util.Util;

/**
 * Caption for figure or table.
 *
 * @param <O>
 *            technology-specific type to access range object.
 * @author tatjana.kostic@ieee.org
 * @version $Id: Caption.java 15 2016-07-12 15:11:42Z dev978 $
 */
public class Caption<O> {

	/**
	 * @author tatjana.kostic@ieee.org
	 * @version $Id: Caption.java 15 2016-07-12 15:11:42Z dev978 $
	 */
	public enum CaptionKind {
		Figure(Style.figcapt), Table(Style.tabcapt);

		private final Style _style;
		private final String _preferredLabel;

		CaptionKind(Style style) {
			_style = style;
			_preferredLabel = name();
		}

		public Style getStyle() {
			return _style;
		}

		public static boolean looksLikeTableCaption(String styleName, String text) {
			return text.startsWith(CaptionKind.Table.getPreferredLabel())
					&& Style.usableForTableCaption(styleName);
		}

		public static boolean looksLikeFigureCaption(String styleName, String text) {
			return text.startsWith(CaptionKind.Figure.getPreferredLabel())
					&& Style.usableForFigureCaption(styleName);
		}

		public String getPreferredLabel() {
			return _preferredLabel;
		}
	}

	private final CaptionKind _kind;
	private final Range<O> _range;

	/**
	 * Constructor.
	 *
	 * @param kind
	 */
	public Caption(CaptionKind kind, Range<O> range) {
		Util.ensureNotNull(kind, "kind");
		Util.ensureNotNull(range, "range");

		_kind = kind;
		_range = range;
	}

	public final CaptionKind getKind() {
		return _kind;
	}

	public Range<O> getRange() {
		return _range;
	}

	public Style getStyle() {
		return getKind().getStyle();
	}

	public String getLabel() {
		return getKind().getPreferredLabel();
	}

	@Override
	public String toString() {
		return String.format(" %s: %s caption", getRange().toString(), getLabel());
	}
}
